@@ -43,9 +43,9 @@
 #include <ksharedconfig.h>
 #include <kcolorscheme.h>
 
-#ifndef UNIT_TEST
 #include <config-platformtheme.h>
-#else
+#ifdef UNIT_TEST
+#undef HAVE_X11
 #define HAVE_X11 0
 #endif
 #if HAVE_X11
@@ -55,16 +55,20 @@
 
 static const QString defaultLookAndFeelPackage = QStringLiteral("org.kde.breeze.desktop");
 
-KHintsSettings::KHintsSettings() : QObject(0)
+KHintsSettings::KHintsSettings(KSharedConfig::Ptr kdeglobals)
+    : QObject(0)
+    , mKdeGlobals(kdeglobals)
 {
-    mKdeGlobals = KSharedConfig::openConfig(QStringLiteral("kdeglobals"), KConfig::NoGlobals);
+    if (!mKdeGlobals) {
+        mKdeGlobals = KSharedConfig::openConfig();
+    }
     KConfigGroup cg(mKdeGlobals, "KDE");
 
     // try to extract the proper defaults file from a lookandfeel package
     const QString looknfeel = cg.readEntry("LookAndFeelPackage", defaultLookAndFeelPackage);
-    mDefaultLnfConfig = KSharedConfig::openConfig(QStandardPaths::locate(QStandardPaths::GenericDataLocation, "plasma/look-and-feel/" + looknfeel + "/contents/defaults"));
+    mDefaultLnfConfig = KSharedConfig::openConfig(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("plasma/look-and-feel/") + looknfeel + QStringLiteral("/contents/defaults")));
     if (looknfeel != defaultLookAndFeelPackage) {
-        mLnfConfig = KSharedConfig::openConfig(QStandardPaths::locate(QStandardPaths::GenericDataLocation, "plasma/look-and-feel/" + defaultLookAndFeelPackage + "/contents/defaults"));
+        mLnfConfig = KSharedConfig::openConfig(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("plasma/look-and-feel/") + defaultLookAndFeelPackage + QStringLiteral("/contents/defaults")));
     }
 
 
@@ -81,17 +85,22 @@ KHintsSettings::KHintsSettings() : QObject(0)
 
     m_hints[QPlatformTheme::ItemViewActivateItemOnSingleClick] = cg.readEntry("SingleClick", true);
 
-    m_hints[QPlatformTheme::SystemIconThemeName] = readConfigValue(QStringLiteral("Icons"), QStringLiteral("Theme"), "breeze");
+    m_hints[QPlatformTheme::SystemIconThemeName] = readConfigValue(QStringLiteral("Icons"), QStringLiteral("Theme"), QStringLiteral("breeze"));
 
-    m_hints[QPlatformTheme::SystemIconFallbackThemeName] = "hicolor";
+    m_hints[QPlatformTheme::SystemIconFallbackThemeName] = QStringLiteral("hicolor");
     m_hints[QPlatformTheme::IconThemeSearchPaths] = xdgIconThemePaths();
 
-    QStringList styleNames;
-    styleNames << cg.readEntry("widgetStyle", QString())
-               << QStringLiteral("breeze")
-               << QStringLiteral("oxygen")
-               << QStringLiteral("fusion")
-               << QStringLiteral("windows");
+    QStringList styleNames{
+        QStringLiteral(BREEZE_STYLE_NAME),
+        QStringLiteral("oxygen"),
+        QStringLiteral("fusion"),
+        QStringLiteral("windows")
+    };
+    const QString configuredStyle = cg.readEntry("widgetStyle", QString());
+    if (!configuredStyle.isEmpty()) {
+        styleNames.removeOne(configuredStyle);
+        styleNames.prepend(configuredStyle);
+    }
     const QString lnfStyle = readConfigValue(QStringLiteral("KDE"), QStringLiteral("widgetStyle"), QString()).toString();
     if (!lnfStyle.isEmpty()) {
         styleNames.removeOne(lnfStyle);
@@ -146,9 +155,10 @@ QVariant KHintsSettings::readConfigValue(const QString &group, const QString &ke
         }
     }
 
-    KConfigGroup lnfCg(mDefaultLnfConfig, group);
+    KConfigGroup lnfCg(mDefaultLnfConfig, "kdeglobals");
+    lnfCg = KConfigGroup(&lnfCg, group);
     if (lnfCg.isValid()) {
-        return lnfCg.readEntry(key, defaultValue);
+        return  lnfCg.readEntry(key, defaultValue);
     }
 
     return defaultValue;
@@ -261,7 +271,7 @@ void KHintsSettings::slotNotifyChange(int type, int arg)
 
         QStringList styleNames;
         styleNames << cg.readEntry("widgetStyle", QString())
-                << QStringLiteral("breeze")
+                << QStringLiteral(BREEZE_STYLE_NAME)
                 << QStringLiteral("oxygen")
                 << QStringLiteral("fusion")
                 << QStringLiteral("windows");
@@ -284,7 +294,7 @@ void KHintsSettings::iconChanged(int group)
 {
     KIconLoader::Group iconGroup = (KIconLoader::Group) group;
     if (iconGroup != KIconLoader::MainToolbar) {
-        m_hints[QPlatformTheme::SystemIconThemeName] = readConfigValue(QStringLiteral("Icons"), QStringLiteral("Theme"), "breeze");
+        m_hints[QPlatformTheme::SystemIconThemeName] = readConfigValue(QStringLiteral("Icons"), QStringLiteral("Theme"), QStringLiteral("breeze"));
 
         return;
     }
@@ -359,20 +369,14 @@ void KHintsSettings::loadPalettes()
 
         KConfigGroup cg(mKdeGlobals, "KDE");
         const QString looknfeel = cg.readEntry("LookAndFeelPackage", defaultLookAndFeelPackage);
-        QString path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "plasma/look-and-feel/" + looknfeel + "/contents/colors");
+        QString path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("plasma/look-and-feel/") + looknfeel + QStringLiteral("/contents/colors"));
         if (!path.isEmpty()) {
             m_palettes[QPlatformTheme::SystemPalette] = new QPalette(KColorScheme::createApplicationPalette(KSharedConfig::openConfig(path)));
             return;
         }
 
-        path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("plasma/look-and-feel/org.kde.loonandfeel/contents/colors"));
-        if (!path.isEmpty()) {
-            m_palettes[QPlatformTheme::SystemPalette] = new QPalette(KColorScheme::createApplicationPalette(KSharedConfig::openConfig(path)));
-            return;
-        }
-
-        const QString scheme = readConfigValue(QStringLiteral("General"), QStringLiteral("ColorScheme"), "Breeze").toString();
-        path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "color-schemes/" + scheme + ".colors");
+        const QString scheme = readConfigValue(QStringLiteral("General"), QStringLiteral("ColorScheme"), QStringLiteral("Breeze")).toString();
+        path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("color-schemes/") + scheme + QStringLiteral(".colors"));
 
         if (!path.isEmpty()) {
             m_palettes[QPlatformTheme::SystemPalette] = new QPalette(KColorScheme::createApplicationPalette(KSharedConfig::openConfig(path)));
@@ -385,7 +389,6 @@ void KHintsSettings::updateCursorTheme()
     KConfig config(QStringLiteral("kcminputrc"));
     KConfigGroup g(&config, "Mouse");
 
-    QString theme = g.readEntry("cursorTheme", QString());
     int size      = g.readEntry("cursorSize", -1);
 
     // Default cursor size is 16 points
@@ -399,6 +402,7 @@ void KHintsSettings::updateCursorTheme()
 
 #if HAVE_X11
     if (QX11Info::isPlatformX11()) {
+        const QString theme = g.readEntry("cursorTheme", QString());
         // Note that in X11R7.1 and earlier, calling XcursorSetTheme()
         // with a NULL theme would cause Xcursor to use "default", but
         // in 7.2 and later it will cause it to revert to the theme that
